#!/bin/bash

# Don't change the following variables here. Instead 
# change the values in /etc/default/ethersrv-linux.

CONFFILE='/etc/default/ethersrv-linux'
ADAPTER=$(ip route get 8.8.8.8 | awk -- '{ print $5; exit }')
IMAGE='/var/lib/ethersrv-linux/dosdrive.img'
DOSDRIVE='/media/ethersrv-linux'

# You can change the SIZE, but then you also have to delete 
# the existing image /var/lib/ethersrv-linux/dosdrive.img. 
# Restarting ethersrv-linux will then create a new image  
# with the new size. Use values with KB, MB or GB.

SIZE=500MB


make_dosdrive() {
	# Make a FAT drive image and format it,
	# but only if the user didn't specify an own directory
	# and only if there is not already an image.

	# Set the configuration file as source (.)
	if [ -f $CONFFILE ]; then
		. $CONFFILE
	fi
	# Check if the option $directory in $CONFFILE 
	# is not set or empty.
	if [ -z "$directory" ]; then 
		if [ ! -f $IMAGE ]; then
		    # Use truncate instead of fallocate to make it work with ZFS
		    # fallocate -l $SIZE $IMAGE
		    truncate -s $SIZE $IMAGE
		    mkfs.fat -n DOSDRIVE $IMAGE
		fi
	fi
}

mount_dosdrive() {
	# Mount the image file, but only if the user did not specify
	# an own directory in $CONFFILE.

	# Set the configuration file as source (.)
	if [ -f $CONFFILE ]; then
		. $CONFFILE
	fi
	# Check if the option $directory in $CONFFILE 
	# is not set or empty.
	if [ -z "$directory" ]; then 
		# The img-file is mounted as FAT (-t msdos), with 
		# directory permissions 755 (dmask=0022),
		# file permissions 644 (fmask=133) and with the 
		# user and group ID of the main user.
		if [ -f $IMAGE ]; then
		    mount -t msdos -o loop $IMAGE $DOSDRIVE -o dmask=0022,fmask=0133,gid=1000,uid=1000
		fi
	fi
}


start_program() {
	# Set the configuration file as source (.)
	if [ -f $CONFFILE ]; then
		. $CONFFILE
	fi

	# If the user set options in $CONFFILE, let them override our own ones.
	if [ -n "$iface" ]; then 
		ADAPTER=$iface
	fi

	if [ -n "$directory" ]; then 
		DOSDRIVE=$directory
	fi

	# Start the program and run it in the background:
	exec /usr/sbin/ethersrv-linux $ADAPTER $DOSDRIVE &>/dev/null &
}


umount_dosdrive() {
	# Unmount only if it is mounted...
	if grep -qs $DOSDRIVE /proc/mounts; then
		/bin/umount -l $DOSDRIVE
	fi
}


start() {
	make_dosdrive
	mount_dosdrive
	start_program
}


stop() {
	umount_dosdrive
	exec killall ethersrv-linux
}

case $1 in
  start|stop) "$1" ;;
esac
